package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.AlarmInfoMapper;
import com.zyc.system.domain.AlarmInfo;
import com.zyc.system.service.IAlarmInfoService;

/**
 * 告警信息Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class AlarmInfoServiceImpl implements IAlarmInfoService 
{
    @Autowired
    private AlarmInfoMapper alarmInfoMapper;

    /**
     * 查询告警信息
     * 
     * @param id 告警信息主键
     * @return 告警信息
     */
    @Override
    public AlarmInfo selectAlarmInfoById(Integer id)
    {
        return alarmInfoMapper.selectAlarmInfoById(id);
    }

    /**
     * 查询告警信息列表
     * 
     * @param alarmInfo 告警信息
     * @return 告警信息
     */
    @Override
    public List<AlarmInfo> selectAlarmInfoList(AlarmInfo alarmInfo)
    {
        return alarmInfoMapper.selectAlarmInfoList(alarmInfo);
    }

    /**
     * 新增告警信息
     * 
     * @param alarmInfo 告警信息
     * @return 结果
     */
    @Override
    public int insertAlarmInfo(AlarmInfo alarmInfo)
    {
        return alarmInfoMapper.insertAlarmInfo(alarmInfo);
    }

    /**
     * 修改告警信息
     * 
     * @param alarmInfo 告警信息
     * @return 结果
     */
    @Override
    public int updateAlarmInfo(AlarmInfo alarmInfo)
    {
        return alarmInfoMapper.updateAlarmInfo(alarmInfo);
    }

    /**
     * 批量删除告警信息
     * 
     * @param ids 需要删除的告警信息主键
     * @return 结果
     */
    @Override
    public int deleteAlarmInfoByIds(Integer[] ids)
    {
        return alarmInfoMapper.deleteAlarmInfoByIds(ids);
    }

    /**
     * 删除告警信息信息
     * 
     * @param id 告警信息主键
     * @return 结果
     */
    @Override
    public int deleteAlarmInfoById(Integer id)
    {
        return alarmInfoMapper.deleteAlarmInfoById(id);
    }
}
